base Package
============

:mod:`base` Package
-------------------

.. automodule:: stoqlib.reporting.base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`defaultstyle` Module
---------------------------

.. automodule:: stoqlib.reporting.base.defaultstyle
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`flowables` Module
-----------------------

.. automodule:: stoqlib.reporting.base.flowables
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`printing` Module
----------------------

.. automodule:: stoqlib.reporting.base.printing
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tables` Module
--------------------

.. automodule:: stoqlib.reporting.base.tables
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`template` Module
----------------------

.. automodule:: stoqlib.reporting.base.template
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: stoqlib.reporting.base.utils
    :members:
    :undoc-members:
    :show-inheritance:

